function [ param,modified ] = param_init_quad( param )
%PARAM_INIT_QUAD generates/checks the input parameter struct
%  param = PARAM        returns a default setting
%  param = PARAM(param) returns a valid parameter setting
%
%  This file is part of the FUNM_QUAD code described in 
%
%   A. Frommer, S. G\"{u}ttel, and M. Schweitzer (2014): Efficient and 
%   stable Arnoldi restarts for matrix functions based on quadrature.
%


modified = 0;

if ~nargin
    param = struct;
    modified = 1;
end

if ~isfield(param,'function')
    param.function = 'invSqrt';
    disp('Warning: .function not specified, set to invSqrt.');
end

if ~isfield(param,'tol')
    param.tol = 1e-13;
    disp('Warning: .tol not specified, set to 1e-13.');
end
    
if ~isfield(param,'thick')
    param.thick = [];
    disp('Warning: .thick not specified, set to [].');
    modified = 1;
end

if ~isfield(param,'inner_product')
    param.inner_product = @inner_product;
    disp('Warning: .inner_product not specified, set to @inner_product.');
    modified = 1;
end

if ~isfield(param,'V_full')
    param.V_full = false;
    disp('Warning: .V_full not specified, set to false.');
    modified = 1;
end

if ~isfield(param,'H_full')
    param.H_full = true;
    disp('Warning: .H_full not specified, set to true.');
    modified = 1;
end

if ~isfield(param,'restart_length')
    param.restart_length = 20;
    disp('Warning: .restart_length not specified, set to 20.');
    modified = 1;
end

if ~isfield(param,'max_restarts')
    param.max_restarts = 10;
    disp('Warning: .max_restarts not specified, set to 10.');
    modified = 1;
end

if ~isfield(param,'hermitian')
    param.hermitian = false;
    disp('Warning: .hermitian not specified, set to false.');
    modified = 1;
end

if isa(param.function,'function_handle') && param.hermitian == false
    disp('Warning: passing a function handle as param.function is only recommended for Hermitian matrices due to possible instabilities in the diagonalization');
end


if ~isfield(param,'reorth_number')
    param.reorth_number = 0;
    disp('Warning: .reorth_number not specified, set to 0.');
    modified = 1;
end


if ~isfield(param,'exact')
    param.exact = [];
    disp('Warning: .exact not specified, no error available.');
    modified = 1;
end

if ~isfield(param,'stopping_accuracy')
    param.stopping_accuracy = 1e-12;
    disp('Warning: .stopping_accuracy not specified, set to 1e-12.');
    modified = 1;
end

if ~isfield(param,'min_decay')
    param.min_decay = 0.95;
    disp('Warning: .min_decay not specified, set to 0.95.');
    modified = 1;
end

if ~isfield(param,'waitbar')
    param.waitbar = true;
    disp('Warning: .waitbar not specified, set to true.');
end

if ~isempty(param.thick) && ~isfield(param,'number_thick')
    param.number_thick = 5;
    disp('Warning: .number_thick not specified, set to 5.');
end

if ~isfield(param,'transformation_parameter') && strcmp(param.function,'invSqrt')
    param.transformation_parameter = 1;
    disp('Warning: .transformation_parameter not specified, set to 1.');
end

if ~isfield(param,'truncation_length'),
    param.truncation_length = inf;
end;